@@ -13,14 +13,16 @@ public:
 	~SpectrumAnalyzer();
 
 	void setColor(QColor color);
-	void Start(){m_playing=true;}
-	void Stop(){m_playing=false;}
+        void Start();
+        void Stop();
 
 protected:
 	void paintEvent(QPaintEvent *event);
 	void mousePressEvent(QMouseEvent *event);
 
 private:
+
+        QTimer* m_pTimer;
 	QColor m_color;
 	int m_width;
 	int m_height;
