@@ -1,4 +1,5 @@
 #include "error.h"
+#include <QDebug>
 
 
 Spotify::Error::Error():
@@ -18,5 +19,7 @@ QString Spotify::Error::toString() const
 
 bool Spotify::Error::isError() const
 {
+    if(m_error != SP_ERROR_OK)
+        qDebug() << "Error code: " << m_error;
     return ( m_error != SP_ERROR_OK );
 }
