@@ -160,7 +160,9 @@ void Spotify::Session::init()
     m_config.settings_location = settingsPath.data();
     m_config.application_key = g_appkey;
     m_config.application_key_size = g_appkey_size;
+    m_config.device_id = "N900";
     m_config.user_agent = "QSpot";
+    m_config.tracefile = NULL;
     m_config.callbacks = &g_callbacks;
 
     // Initiate  / allocate new session
