@@ -4,578 +4,496 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../src/AboutDialog.cpp" line="12"/>
         <source>Done</source>
-        <translation type="unfinished"></translation>
+        <translation>OK</translation>
     </message>
 </context>
 <context>
     <name>AlbumView</name>
     <message>
-        <location filename="../src/AlbumView.cpp" line="10"/>
-        <source>Browse Album</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/AlbumView.cpp" line="12"/>
-        <location filename="../src/AlbumView.cpp" line="53"/>
         <source>Album Review</source>
-        <translation type="unfinished"></translation>
+        <translation>Album Bespreking</translation>
     </message>
     <message>
-        <location filename="../src/AlbumView.cpp" line="101"/>
         <source>Fetching of album details failed!</source>
-        <translation type="unfinished"></translation>
+        <translation>Ophalen van albuminformatie mislukt!</translation>
+    </message>
+    <message>
+        <source>Browse Album</source>
+        <translation>Album Doorbladeren</translation>
     </message>
     <message>
-        <location filename="../src/AlbumView.cpp" line="134"/>
         <source>Fetching of album details failed: </source>
-        <translation type="unfinished"></translation>
+        <translation>Ophalen van albuminformaties mislukt:</translation>
     </message>
 </context>
 <context>
     <name>ArtistView</name>
     <message>
-        <location filename="../src/artistview.cpp" line="12"/>
-        <source>Browse Artist</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/artistview.cpp" line="14"/>
         <source>Artist Biography</source>
-        <translation type="unfinished"></translation>
+        <translation>Biografie Artiest</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="44"/>
-        <source>Biography</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/artistview.cpp" line="81"/>
-        <source>Fetching of artist details failed!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/artistview.cpp" line="86"/>
         <source>Loading </source>
-        <translation type="unfinished"></translation>
+        <translation>Laden</translation>
+    </message>
+    <message>
+        <source>Biography</source>
+        <translation>Biografie</translation>
+    </message>
+    <message>
+        <source>Fetching of artist details failed!</source>
+        <translation>Ophalen van artiest informatie mislukt!</translation>
     </message>
     <message>
-        <location filename="../src/artistview.cpp" line="106"/>
         <source>Fetching of artist details failed: </source>
-        <translation type="unfinished"></translation>
+        <translation>Ophalen van artiest informatie mislukt:</translation>
+    </message>
+    <message>
+        <source>Browse Artist</source>
+        <translation>Artiest Doorbladeren</translation>
     </message>
 </context>
 <context>
     <name>LoginDialog</name>
     <message>
-        <location filename="../src/logindialog.cpp" line="21"/>
-        <source>QSpot - Login</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="24"/>
-        <source>UserID:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="26"/>
-        <source>Password:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="29"/>
-        <location filename="../src/logindialog.cpp" line="180"/>
-        <source>Remember UserID and password</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="35"/>
-        <source>Low bitrate (96kbps)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="35"/>
-        <source>Standard bitrate (160kbps)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="36"/>
-        <source>High bitrate (320kbps)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="44"/>
-        <source>Preferred bitrate</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/logindialog.cpp" line="48"/>
         <source>Login</source>
-        <translation type="unfinished"></translation>
+        <translation>Meld aan</translation>
     </message>
     <message>
-        <location filename="../src/logindialog.cpp" line="186"/>
         <source>Remember UserID &amp;&amp; Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Onthoud gebruikersnaam &amp;&amp; wachtwoord</translation>
+    </message>
+    <message>
+        <source>Low bitrate (96kbps)</source>
+        <translation type="obsolete">Laag (96kbps)</translation>
+    </message>
+    <message>
+        <source>Preferred bitrate</source>
+        <translation type="obsolete">Voorkeurskwaliteit</translation>
+    </message>
+    <message>
+        <source>High bitrate (320kbps)</source>
+        <translation type="obsolete">Hoog (320kbps)</translation>
+    </message>
+    <message>
+        <source>QSpot - Login</source>
+        <translation>QSpot - Aanmelden</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Wachtwoord:</translation>
+    </message>
+    <message>
+        <source>UserID:</source>
+        <translation>Gebruikersnaam:</translation>
+    </message>
+    <message>
+        <source>Standard bitrate (160kbps)</source>
+        <translation type="obsolete">Standaard (160kbps)</translation>
+    </message>
+    <message>
+        <source>Remember UserID and password</source>
+        <translation type="obsolete">Onthoud gebruikersnaam en wachtwoord</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="18"/>
-        <source>QSpot - Playlists</source>
-        <translation type="unfinished"></translation>
+        <source>Timeout occured while loading playlists!</source>
+        <translation>De afspeellijst kon niet worden geladen binnen de gestelde limiet!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="62"/>
-        <location filename="../src/MainWindow.cpp" line="570"/>
-        <source>Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="63"/>
-        <location filename="../src/MainWindow.cpp" line="576"/>
-        <source>FM Transmitter</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="64"/>
-        <location filename="../src/MainWindow.cpp" line="580"/>
         <source>About</source>
-        <translation type="unfinished"></translation>
+        <translation>Over</translation>
+    </message>
+    <message>
+        <source>Error:</source>
+        <translation>Fout:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="179"/>
         <source>About QSpot</source>
-        <translation type="unfinished"></translation>
+        <translation>Over QSpot</translation>
+    </message>
+    <message>
+        <source>Last.fm error: </source>
+        <translation>Last.fm fout:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>QSpot version </source>
-        <translation type="unfinished"></translation>
+        <translation>QSpot versie</translation>
+    </message>
+    <message>
+        <source>FM Transmitter</source>
+        <translation>FM Zender</translation>
+    </message>
+    <message>
+        <source>tracks</source>
+        <translation>titels</translation>
+    </message>
+    <message>
+        <source>Searching</source>
+        <translation>Zoeken</translation>
+    </message>
+    <message>
+        <source>Loading playlists</source>
+        <translation>Laden afspeellijst</translation>
+    </message>
+    <message>
+        <source>Error: </source>
+        <translation>Fout:</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Instellingen</translation>
+    </message>
+    <message>
+        <source>Playback paused due to the same account being used somewhere else!</source>
+        <translation>Afspelen gepauzeerd omdat het account elders wordt gebruikt!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
 
 (C) 2011 Andreas Enbacka and The QSpot Team.
 
-Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo) for the Finnish translations.</source>
-        <translation type="unfinished"></translation>
+Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout.</source>
+        <translation type="obsolete">Een open-source Qt-gebaseerde Spotify client voor de N900/Maemo5 (gebaseerd op libopenspotify).
+
+(C) 2011 Andreas Enbacka en het QSpot Team.
+
+Bijzondere dank voor Markus (markusm@tmo) voor ondersteuning bij het grafische ontwerp en opmaak.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="406"/>
-        <source>Error:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="419"/>
-        <source>Loading playlists</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="436"/>
-        <source>Timeout occured while loading playlists!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="464"/>
-        <source>tracks</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="602"/>
-        <source>Searching</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="608"/>
-        <location filename="../src/MainWindow.cpp" line="623"/>
-        <source>Error: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="642"/>
         <source>No tracks found!</source>
+        <translation>Geen titels gevonden!</translation>
+    </message>
+    <message>
+        <source>QSpot - Playlists</source>
+        <translation>QSpot - Afspeellijst</translation>
+    </message>
+    <message>
+        <source>Logging in to Spotify</source>
+        <translation>Inloggen bij Spotify</translation>
+    </message>
+    <message>
+        <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
+
+(C) 2011 Andreas Enbacka and The QSpot Team.
+
+Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) for the translations.</source>
+        <translation>Een open-source Qt-gebaseerde Spotify client voor de N900/Maemo5 (gebaseerd op libopenspotify).
+
+(C) 2011 Andreas Enbacka en het QSpot Team.
+
+Bijzondere dank aan Markus (markusm@tmo) voor ondersteuning bij het grafische ontwerp en opmaak, en aan Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) voor de vertalingen.</translation>
+    </message>
+    <message>
+        <source>Failed to re-authenticate with Spotify</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="656"/>
-        <source>Playback paused due to the same account being used somewhere else!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="666"/>
-        <source>Last.fm error: </source>
+        <source>No suitable internet access point(s) found!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>QueueView</name>
     <message>
-        <location filename="../src/QueueView.cpp" line="15"/>
-        <location filename="../src/QueueView.cpp" line="859"/>
-        <location filename="../src/QueueView.cpp" line="868"/>
-        <location filename="../src/QueueView.cpp" line="1012"/>
-        <source>Now Playing</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="179"/>
-        <source>Play Album</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="182"/>
         <source>Browse Album</source>
-        <translation type="unfinished"></translation>
+        <translation>Album Doorbladeren</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="185"/>
-        <source>Browse Artist</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="199"/>
-        <location filename="../src/QueueView.cpp" line="206"/>
-        <source>FM Transmitter</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="386"/>
-        <location filename="../src/QueueView.cpp" line="518"/>
-        <location filename="../src/QueueView.cpp" line="803"/>
-        <location filename="../src/QueueView.cpp" line="822"/>
-        <source>Error starting track playback: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="514"/>
-        <source>Buffering</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="868"/>
-        <location filename="../src/QueueView.cpp" line="872"/>
-        <location filename="../src/QueueView.cpp" line="1012"/>
-        <location filename="../src/QueueView.cpp" line="1045"/>
-        <source>Shuffle</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="933"/>
-        <source>Loading album tracks</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/QueueView.cpp" line="954"/>
         <source>Fetching of album tracks failed: </source>
-        <translation type="unfinished"></translation>
+        <translation>Ophalen van album mislukt:</translation>
+    </message>
+    <message>
+        <source>Loading album tracks</source>
+        <translation>Ophalen album</translation>
+    </message>
+    <message>
+        <source>Error starting track playback: </source>
+        <translation>Fout bij begin afspelen:</translation>
+    </message>
+    <message>
+        <source>FM Transmitter</source>
+        <translation>FM Zender</translation>
+    </message>
+    <message>
+        <source>Now Playing</source>
+        <translation>Afspelen</translation>
+    </message>
+    <message>
+        <source>Shuffle</source>
+        <translation>Shuffle</translation>
+    </message>
+    <message>
+        <source>Play Album</source>
+        <translation>Album Afspelen</translation>
+    </message>
+    <message>
+        <source>Buffering</source>
+        <translation>Bufferen</translation>
+    </message>
+    <message>
+        <source>Browse Artist</source>
+        <translation>Artiest Doorbladeren</translation>
     </message>
     <message>
-        <location filename="../src/QueueView.cpp" line="960"/>
         <source>Failed to load tracks!</source>
-        <translation type="unfinished"></translation>
+        <translation>Laden titels mislukt!</translation>
     </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
-        <source>Landscape</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
-        <source>Portrait</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="62"/>
-        <source>Automatic</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="118"/>
-        <location filename="../src/SettingsDialog.cpp" line="142"/>
-        <source>QSpot - Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="119"/>
-        <source>Max. tracks returned</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="120"/>
-        <source>Max. albums returned</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="121"/>
-        <source>Max. artists returned</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="122"/>
-        <location filename="../src/SettingsDialog.cpp" line="146"/>
-        <source>Search settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="123"/>
-        <location filename="../src/SettingsDialog.cpp" line="147"/>
-        <source>Buffering settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="124"/>
-        <source>Min. buffering length (secs)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="125"/>
-        <source>Enable track pre-buffering</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="126"/>
-        <location filename="../src/SettingsDialog.cpp" line="150"/>
-        <source>UI Language</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="127"/>
-        <location filename="../src/SettingsDialog.cpp" line="151"/>
-        <source>Display orientation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="128"/>
-        <location filename="../src/SettingsDialog.cpp" line="152"/>
-        <source>Playlist options</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="129"/>
-        <source>Playlist load timeout (secs)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="130"/>
-        <location filename="../src/SettingsDialog.cpp" line="154"/>
-        <source>Pause on headset unplugged</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="131"/>
-        <location filename="../src/SettingsDialog.cpp" line="155"/>
-        <source>Scrobbling options</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="132"/>
-        <source>Enable scrobbling to Last.fm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="133"/>
-        <location filename="../src/SettingsDialog.cpp" line="157"/>
-        <source>Last.fm username</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="134"/>
-        <location filename="../src/SettingsDialog.cpp" line="158"/>
-        <source>Last.fm password</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="135"/>
-        <location filename="../src/SettingsDialog.cpp" line="159"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Opslaan</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="143"/>
-        <source>Max. tracks</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="144"/>
-        <source>Max. albums</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="145"/>
-        <source>Max. artists</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="148"/>
-        <source>Min.buff.length (secs)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="149"/>
-        <source>Enable track pre-buff.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="153"/>
-        <source>Playlist load TO (secs)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/SettingsDialog.cpp" line="156"/>
         <source>Enable Last.fm scrobbling</source>
-        <translation type="unfinished"></translation>
+        <translation>Verzenden naar Last.fm toestaan</translation>
+    </message>
+    <message>
+        <source>Buffering settings</source>
+        <translation>Buffer instellingen</translation>
+    </message>
+    <message>
+        <source>Max. tracks returned</source>
+        <translation>Max. aantal titels ontvangen</translation>
+    </message>
+    <message>
+        <source>Search settings</source>
+        <translation>Zoek instellingen</translation>
+    </message>
+    <message>
+        <source>Enable scrobbling to Last.fm</source>
+        <translation>Verzenden naar Last.fm toestaan</translation>
+    </message>
+    <message>
+        <source>Enable track pre-buffering</source>
+        <translation>Bufferen aanzetten</translation>
+    </message>
+    <message>
+        <source>Landscape</source>
+        <translation>Horizontaal</translation>
+    </message>
+    <message>
+        <source>Min.buff.length (secs)</source>
+        <translation>Min.buff.lengte (s)</translation>
+    </message>
+    <message>
+        <source>Playlist load TO (secs)</source>
+        <translation>Limiet laadtijd afspeellijst (s)</translation>
+    </message>
+    <message>
+        <source>Display orientation</source>
+        <translation>Scherm oriëntatie</translation>
+    </message>
+    <message>
+        <source>Max. albums</source>
+        <translation>Max. albums</translation>
+    </message>
+    <message>
+        <source>Playlist options</source>
+        <translation>Afspeellijst instellingen</translation>
+    </message>
+    <message>
+        <source>Portrait</source>
+        <translation>Verticaal</translation>
+    </message>
+    <message>
+        <source>Max. artists returned</source>
+        <translation>Max. artiesten ontvangen</translation>
+    </message>
+    <message>
+        <source>Max. tracks</source>
+        <translation>Max. titels</translation>
+    </message>
+    <message>
+        <source>Pause on headset unplugged</source>
+        <translation>Pauzeer bij verwijderen headset</translation>
+    </message>
+    <message>
+        <source>Scrobbling options</source>
+        <translation>Verzend instellingen</translation>
+    </message>
+    <message>
+        <source>Enable track pre-buff.</source>
+        <translation>Sta titel buffer toe</translation>
+    </message>
+    <message>
+        <source>QSpot - Settings</source>
+        <translation>QSpot - Instellingen</translation>
+    </message>
+    <message>
+        <source>Automatic</source>
+        <translation>Automatisch</translation>
+    </message>
+    <message>
+        <source>Min. buffering length (secs)</source>
+        <translation>Min.buffer lengte (s)</translation>
+    </message>
+    <message>
+        <source>Max. artists</source>
+        <translation>Max. artiesten</translation>
+    </message>
+    <message>
+        <source>Max. albums returned</source>
+        <translation>Max. aantal albums ontvangen</translation>
+    </message>
+    <message>
+        <source>Last.fm username</source>
+        <translation>Last.fm gebruikersnaam</translation>
+    </message>
+    <message>
+        <source>Playlist load timeout (secs)</source>
+        <translation>Limiet laadtijd afspeellijst (s)</translation>
+    </message>
+    <message>
+        <source>Last.fm password</source>
+        <translation>Last.fm wachtwoord</translation>
+    </message>
+    <message>
+        <source>UI Language</source>
+        <translation>Taal Instelling</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="275"/>
         <source>Please restart QSpot for language change to take effect!</source>
+        <translation>Herstart QSpot om de aangepaste taalinstelling toe te passen!</translation>
+    </message>
+    <message>
+        <source>Remember UserID and password</source>
+        <translation>Onthoud gebruikersnaam en wachtwoord</translation>
+    </message>
+    <message>
+        <source>Low bitrate (96kbps)</source>
+        <translation>Laag (96kbps)</translation>
+    </message>
+    <message>
+        <source>Standard bitrate (160kbps)</source>
+        <translation>Standaard (160kbps)</translation>
+    </message>
+    <message>
+        <source>High bitrate (320kbps)</source>
+        <translation>Hoog (320kbps)</translation>
+    </message>
+    <message>
+        <source>Preferred bitrate</source>
+        <translation>Voorkeurskwaliteit</translation>
+    </message>
+    <message>
+        <source>Please restart QSpot for bitrate change to take effect!</source>
+        <translation>Herstart QSpot om de aangepaste kwaliteitsinstelling toe te passen!</translation>
+    </message>
+    <message>
+        <source>Hide coverart in Now Playing</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Spotify::Album</name>
     <message>
-        <location filename="../src/qspotify_src/album.cpp" line="91"/>
         <source>Album</source>
-        <translation type="unfinished"></translation>
+        <translation>Album</translation>
     </message>
     <message>
-        <location filename="../src/qspotify_src/album.cpp" line="93"/>
-        <source>Single</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/qspotify_src/album.cpp" line="95"/>
         <source>Compilation</source>
-        <translation type="unfinished"></translation>
+        <translation>Compilatie</translation>
     </message>
     <message>
-        <location filename="../src/qspotify_src/album.cpp" line="97"/>
-        <location filename="../src/qspotify_src/album.cpp" line="110"/>
-        <source>Appears on</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/qspotify_src/album.cpp" line="104"/>
         <source>Albums</source>
-        <translation type="unfinished"></translation>
+        <translation>Albums</translation>
     </message>
     <message>
-        <location filename="../src/qspotify_src/album.cpp" line="106"/>
-        <source>Singles</source>
-        <translation type="unfinished"></translation>
+        <source>Single</source>
+        <translation>Single</translation>
     </message>
     <message>
-        <location filename="../src/qspotify_src/album.cpp" line="108"/>
         <source>Compilations</source>
-        <translation type="unfinished"></translation>
+        <translation>Compilaties</translation>
+    </message>
+    <message>
+        <source>Singles</source>
+        <translation>Singles</translation>
+    </message>
+    <message>
+        <source>Appears on</source>
+        <translation>Komt voor op</translation>
     </message>
 </context>
 <context>
     <name>TrackView</name>
     <message>
-        <location filename="../src/TrackView.cpp" line="54"/>
-        <source>Play Album</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="57"/>
-        <source>Browse Album</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="60"/>
-        <source>Browse Artist</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="71"/>
         <source>Sort tracks by</source>
-        <translation type="unfinished"></translation>
+        <translation>Sorteer titels op</translation>
     </message>
     <message>
-        <location filename="../src/TrackView.cpp" line="73"/>
-        <source>Playlist order</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="73"/>
-        <location filename="../src/TrackView.cpp" line="76"/>
-        <source>Most popular</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="73"/>
-        <location filename="../src/TrackView.cpp" line="76"/>
-        <source>Track name (ascending)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="73"/>
-        <location filename="../src/TrackView.cpp" line="76"/>
-        <source>Track name (descending)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="73"/>
-        <location filename="../src/TrackView.cpp" line="76"/>
-        <source>Artist name (ascending)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="74"/>
-        <location filename="../src/TrackView.cpp" line="77"/>
-        <source>Artist name (descending)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="74"/>
-        <location filename="../src/TrackView.cpp" line="77"/>
-        <source>Album name (ascending)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="74"/>
-        <location filename="../src/TrackView.cpp" line="77"/>
-        <source>Album name (descending)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="76"/>
-        <source>Artist, album, track (ascending)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="81"/>
-        <location filename="../src/TrackView.cpp" line="190"/>
-        <source>FM Transmitter</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="119"/>
-        <source>Loading album tracks</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="155"/>
-        <source>Fetching of album tracks failed: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="161"/>
-        <source>Failed to load tracks!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/TrackView.cpp" line="273"/>
         <source>Search results: </source>
-        <translation type="unfinished"></translation>
+        <translation>Zoekresultaten:</translation>
+    </message>
+    <message>
+        <source>Browse Album</source>
+        <translation>Album Doorbladeren</translation>
+    </message>
+    <message>
+        <source>Fetching of album tracks failed: </source>
+        <translation>Ophalen van album mislukt:</translation>
+    </message>
+    <message>
+        <source>Most popular</source>
+        <translation>Populairst</translation>
+    </message>
+    <message>
+        <source>Loading album tracks</source>
+        <translation>Album laden</translation>
+    </message>
+    <message>
+        <source>Playlist order</source>
+        <translation>Volgorde afspeellijst</translation>
+    </message>
+    <message>
+        <source>Track name (descending)</source>
+        <translation>Titelnaam (aflopend)</translation>
+    </message>
+    <message>
+        <source>Track name (ascending)</source>
+        <translation>Titelnaam (oplopend)</translation>
+    </message>
+    <message>
+        <source>Artist name (ascending)</source>
+        <translation>Artiestennaam (oplopend)</translation>
+    </message>
+    <message>
+        <source>FM Transmitter</source>
+        <translation>FM-Zender</translation>
+    </message>
+    <message>
+        <source>Album name (descending)</source>
+        <translation>Albumnaam (aflopend)</translation>
+    </message>
+    <message>
+        <source>Album name (ascending)</source>
+        <translation>Albumnaam (oplopend)</translation>
+    </message>
+    <message>
+        <source>Artist, album, track (ascending)</source>
+        <translation>Artiest, album, titel (oplopend)</translation>
+    </message>
+    <message>
+        <source>Play Album</source>
+        <translation>Album Afspelen</translation>
+    </message>
+    <message>
+        <source>Artist name (descending)</source>
+        <translation>Artiestennaam (aflopend)</translation>
+    </message>
+    <message>
+        <source>Browse Artist</source>
+        <translation>Artiest Doorbladeren</translation>
+    </message>
+    <message>
+        <source>Failed to load tracks!</source>
+        <translation>Laden van titels mislukt!</translation>
     </message>
 </context>
 </TS>
